---
slug: /configuration-items-overview
---

# Configurations Overview

You can configure the behaviors of seekdb by setting the parameters in the configuration file.

## Item level

Configuration items that begin with an underscore character are called hidden configuration items, such as `_ob_max_thread_num`. These are available only to developers and for troubleshooting or urgent maintenance scenarios. This topic does not provide detailed information on hidden configuration items. Unless otherwise specified, the configuration items described in the following sections do not include hidden configuration items.

The following table lists the main data types of configuration parameters in SeekDB and their descriptions:

|    Data type     |       Description     |
|-------------|---------|
| BOOL        | A boolean value that supports true or false.     |
| CAPACITY    | The capacity unit, which can be b (bytes), k (KB, kilobytes), m (MB, megabytes), g (GB, gigabytes), t (TB, terabytes), or p (PB, petabytes). The unit is case-insensitive and defaults to m. |
| DOUBLE      | Double-precision floating point value occupying 64 bits. This value has 16 significant decimal digits, including 15 decimal places. |
| INT         | int64, which supports positive integers, negative integers, and 0.             |
| MOMENT      | The time in the `hh:mm` format (for example, `02:00`). You can also set this parameter to `disable` to specify a time for the major freeze. This parameter only applies to the `major_freeze_duty_time` parameter.       |
| STRING      | String. The value of the string that the user inputs.     |
| STRING_LIST | A string list, which is a list of strings separated with semicolons (;).     |
| TIME       | The type of time. Valid units: us (microsecond), ms (millisecond), s (second), m (minute), h (hour), and d (day). If no unit is specified, it is default set to s. The unit is case-insensitive.  |

## View the configuration item's effective method.

Configuration parameters can take effect immediately or only after a restart. Most configuration parameters take effect immediately, without the need to restart seekdb.

The procedure for querying a configuration item is as follows:

```sql
SHOW PARAMETERS LIKE 'max_syslog_file_count';
```

The query result is as follows:

```shell
+-----------------------+-----------+-------+--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+-------------------+---------------+-----------+
| name                  | data_type | value | info                                                                                                                                                                                                                                             | edit_level        | default_value | isdefault |
+-----------------------+-----------+-------+--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+-------------------+---------------+-----------+
| max_syslog_file_count | INT       | 4     | specifies the maximum number of the log files that can co-exist before the log file recycling kicks in. Each log file can occupy at most 256MB disk space. When this value is set to 0, no log file will be removed. Range: [0, +∞) in integer   | DYNAMIC_EFFECTIVE | 4             |         1 |
+-----------------------+-----------+-------+--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+-------------------+---------------+-----------+
1 row in set
```

The following table describes the fields:

* The `edit_level` column indicates the effectiveness of the configuration item, which is typically divided into dynamic effectiveness and restart effectiveness. `dynamic_effective` indicates dynamic effectiveness, while `static_effective` indicates restart effectiveness. Most configuration items are dynamically effective, meaning they take effect without requiring a restart of seekdb.

## References

* [View Parameters](200.view-parameters.md)

* [Modify a parameter](300.modify-parameters.md)

* [Reset parameters](400.reset-parameters.md)

* [Overview of system variables](../300.system-variable/100.system-variable-overview.md)